// Copyright (c)2005, TopCoder, Inc. All rights reserved
// @author TCSDEVELOPER
// @version 2.0

using System;
using System.Collections;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.Util.ConfigurationManager
{
    /// <summary>
    /// IDataHandler interface is responsible for loading or saving namespaces 
    /// to the corresponding datasource. A new IDataHandler instance will be 
    /// created from the configuration values in the mxml file by the PluggableHandler, 
    /// and necessary information will also be passed to it during the instantiation, 
    /// so that it knows which datasource to connect to. 
    /// All implementations of this interface should provide a constructor taking 
    /// an IDictionary argument which contains pairs of string type key-value 
    /// pair to provide necessary information about the datasource.
    /// </summary>
    public interface IDataHandler
    {
        /// <summary>
        /// Loads a list of Namespace instances from the datasource.
        /// This method will be called by the LoadFromFile method of PluggableHandler 
        /// class to load the namespaces from a specific datasource.
        /// </summary>
        /// <param name="errorCallback">
        /// The error handler callback if an error occurs during loading.
        /// </param>
        /// <returns>A list of namespaces read from the datasource.</returns>
        IList Load (ErrorCallback errorCallback);

        /// <summary>
        /// Saves a list of namespaces to the datasource. This method is called by the 
        /// SaveFile method of PluggableHandler to save the namespace list to the 
        /// datasource.
        /// </summary>
        /// <param name="namespacesList">List of namespaces to be saved.</param>
        void Save (IList namespacesList);
    }
}
