/*
 * Copyright (c)2005, TopCoder, Inc. All rights reserved
 * @author sinaddcos
 * @version 2.0
 */
using System;
using NUnit.Framework;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.Util.ConfigurationManager.Test.Accuray
{
    /// <summary>
    /// Test the accuracy of the ParsingPreference class.
    /// </summary>
    [TestFixture]
    public class AccuracyTestParsingPreference
    {
        /// <summary>
        /// The ParsingPreference object used in the test.
        /// </summary>
        private ParsingPreference preference = null;

        /// <summary>
        /// Set up Environment.
        /// </summary>
        [SetUp]
        public void SetUp() 
        {
            preference = new ParsingPreference();
        }

        /// <summary>
        /// Test the Parse functionality of allowing null.
        /// </summary>
        [Test]
        public void TestParseAllowNull()
        {
            preference.AllowNull = true;
            Assert.IsNull(preference.Parse(null));
        }

        /// <summary>
        /// Test the Parse functionarlity of allowing empty string.
        /// </summary>
        [Test]
        public void TestParseAllowEmpty()
        {
            preference.AllowEmpty = true;
            Assert.AreEqual("", preference.Parse(""), "Parse empty string");
        }

        /// <summary>
        /// Test the parsing functinality of trim spaces.
        /// </summary>
        [Test]
        public void TestParseTrimSpace()
        {
            preference.TrimSpace = true;
            Assert.AreEqual("abc", preference.Parse("    abc    "));
        }

        /// <summary>
        /// Test parsing.
        /// </summary>
        [Test]
        public void TestParse()
        {
            preference.AllowNull = true;
            preference.AllowEmpty = true;
            preference.TrimSpace = true;
            Assert.IsNull(preference.Parse(null));
            Assert.AreEqual("", preference.Parse(""), "Parse empty string");
            Assert.AreEqual("abc", preference.Parse("    abc    "));
        }
    }
}
