// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.UnitTests
{
    /// <summary>
    /// Unit tests for the ConfigManager class
    /// </summary>
    [TestFixture]
    public class ConfigManagerUnitTestCase
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;
        
        /// <summary>
        /// Set up.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
			cm.Clear();
        }

        /// <summary>
        /// Tests the Namespaces field of ConfigManager
        /// </summary>
        [Test]
        public void TestNamespaces()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertEquals(4, cm.Namespaces.Length);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            cf = cm.LoadFile(@"..\..\test_files\test3.xml");
            
            Assertion.AssertNotNull(cf);
            Assertion.AssertEquals(3, cm.Namespaces.Length);

            cm.RemoveFile(@"..\..\test_files\test3.xml");

            cf = cm.LoadFile(@"..\..\test_files\test3.xml", "override");
            
            Assertion.AssertNotNull(cf);
            Assertion.AssertEquals(3, cm.Namespaces.Length);

            cm.RemoveFile(@"..\..\test_files\test3.xml");
        }

        /// <summary>
        /// Tests the ConfigFiles field of ConfigManager
        /// </summary>
        [Test]
        public void TestConfigFiles()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertEquals(3, cm.ConfigFiles.Length);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            Assertion.AssertEquals(2, cm.ConfigFiles.Length);

            cf = cm.LoadFile(@"..\..\test_files\test3.xml");
            
            Assertion.AssertNotNull(cf);
            Assertion.AssertEquals(3, cm.ConfigFiles.Length);

            cm.RemoveFile(@"..\..\test_files\test3.xml");

            cf = cm.LoadFile(@"..\..\test_files\test3.xml", "override");
            
            Assertion.AssertNotNull(cf);
            Assertion.AssertEquals(3, cm.ConfigFiles.Length);

            cm.RemoveFile(@"..\..\test_files\test3.xml");

            Assertion.AssertEquals(2, cm.ConfigFiles.Length);
        }

        /// <summary>
        /// Tests the GetConfigFile method of ConfigManager
        /// </summary>
        [Test]
        public void TestGetConfigFile()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertEquals(cf.Namespaces.Length, cm.GetConfigFile(@"..\..\test_files\test.ini").Namespaces.Length);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            Assertion.AssertEquals(1, cm.GetConfigFile(@"..\..\test_files\test1.xml").Namespaces.Length);

        }

        /// <summary>
        /// Tests the GetNamespace method of ConfigManager
        /// </summary>
        [Test]
        public void TestGetNamespace()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertNotNull(cm.GetNamespace("section1"));
            Assertion.AssertEquals("section1", cm.GetNamespace("section1").Name);
            Assertion.AssertEquals(3, cm.GetNamespace("section1").Properties.Length);

            cm.RemoveFile(@"..\..\test_files\test.ini");
        }

        /// <summary>
        /// Tests the indexer of ConfigManager
        /// </summary>
        [Test]
        public void TestIndexer()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertNotNull(cm["section1"]);
            Assertion.AssertEquals("section1", cm["section1"].Name);
            Assertion.AssertEquals(3, cm["section1"].Properties.Length);

            cm.RemoveFile(@"..\..\test_files\test.ini");
        }

        /// <summary>
        /// Tests the GetProperty method of ConfigManager
        /// </summary>
        [Test]
        public void TestGetProperty()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertNotNull(cm.GetProperty("section1", "prop1"));
            Assertion.AssertEquals("prop1", cm.GetProperty("section1", "prop1").Name);
            Assertion.AssertEquals(1, cm.GetProperty("section1", "prop1").Values.Length);
            Assertion.AssertEquals(3, cm.GetProperty("section1", "prop3").Values.Length);
            Assertion.AssertEquals(2, cm.GetProperty("section2", "prop2").Values.Length);

            cm.RemoveFile(@"..\..\test_files\test.ini");
        }

        /// <summary>
        /// Tests the GetValue method of ConfigManager
        /// </summary>
        [Test]
        public void TestGetValue()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertNotNull(cm.GetValue("section1", "prop1"));
            Assertion.AssertEquals("value1", cm.GetValue("section1", "prop1"));
            Assertion.AssertEquals("value1", cm.GetValue("section1", "prop3"));
            Assertion.AssertEquals("value1", cm.GetValue("section2", "prop2"));
            Assertion.AssertEquals("value1", cm.GetValue("section2", "prop3"));

            cm.RemoveFile(@"..\..\test_files\test.ini");
        }

        /// <summary>
        /// Tests the GetValues method of ConfigManager
        /// </summary>
        [Test]
        public void TestGetValues()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertNotNull(cm.GetValues("section1", "prop1"));
            Assertion.AssertEquals(1, cm.GetValues("section1", "prop1").Length);
            Assertion.AssertEquals(3, cm.GetValues("section1", "prop3").Length);
            Assertion.AssertEquals(2, cm.GetValues("section2", "prop2").Length);
            Assertion.AssertEquals(3, cm.GetValues("section2", "prop3").Length);
            Assertion.AssertEquals("value2", cm.GetValues("section2", "prop2")[1]);
            Assertion.AssertEquals("value3", cm.GetValues("section1", "prop3")[2]);
            Assertion.AssertEquals("value1", cm.GetValues("section2", "prop3")[0]);

            cm.RemoveFile(@"..\..\test_files\test.ini");
        }

        /// <summary>
        /// Tests the SetValue method of ConfigManager
        /// </summary>
        [Test]
        public void TestSetValue()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertNotNull(cm.GetValue("section1", "prop1"));
            Assertion.AssertEquals("value1", cm.GetValue("section1", "prop3"));
            Assertion.AssertEquals(3, cm.GetValues("section1", "prop3").Length);
            cm.SetValue("section1", "prop3", "newvalue");
            Assertion.AssertEquals("newvalue", cm.GetValue("section1", "prop3"));
            Assertion.AssertEquals(1, cm.GetValues("section1", "prop3").Length);

            cm.RemoveFile(@"..\..\test_files\test.ini");
        }

        /// <summary>
        /// Tests the SetValues method of ConfigManager
        /// </summary>
        [Test]
        public void TestSetValues()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");

            Assertion.AssertNotNull(cf);
            Assertion.AssertNotNull(cm.GetValue("section1", "prop1"));
            Assertion.AssertEquals("value1", cm.GetValue("section1", "prop3"));
            Assertion.AssertEquals(3, cm.GetValues("section1", "prop3").Length);
            cm.SetValues("section1", "prop3", new string[] {"newvalue1", "newvalue2"});
            Assertion.AssertEquals("newvalue1", cm.GetValue("section1", "prop3"));
            Assertion.AssertEquals(2, cm.GetValues("section1", "prop3").Length);

            cm.RemoveFile(@"..\..\test_files\test.ini");
        }
    }
}
