/*
Copyright (c) 2004, TopCoder, Inc. All rights reserved.
Author: WishingBone
*/

using System;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.FailureTests
{

    /// <summary>
    /// Failure test fixture for DefaultStringConverter.
    /// </summary>
    [TestFixture]
    public class StringConverterFailureTests
    {

        /// <summary>
        /// The DefaultStringConverter instance.
        /// </summary>
        private IStringConverter converter = DefaultStringConverter.Instance;

        /// <summary>
        /// Convert null value.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void ConvertNullValue()
        {
            converter.Convert(null, typeof(int));
        }

        /// <summary>
        /// Convert empty value.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentException))]
        public void ConvertEmptyValue()
        {
            converter.Convert(string.Empty, typeof(int));
        }

        /// <summary>
        /// Convert to null type.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void ConvertNullType()
        {
            converter.Convert("12", null);
        }

        /// <summary>
        /// Convert to incompatible type.
        /// </summary>
        [Test, ExpectedException(typeof(NotSupportedException))]
        public void ConvertIncompatibleType1()
        {
            converter.Convert("twelve", typeof(int));
        }

        /// <summary>
        /// Convert to incompatible type.
        /// </summary>
        [Test, ExpectedException(typeof(NotSupportedException))]
        public void ConvertIncompatibleType2()
        {
            converter.Convert("today", typeof(DateTime));
        }

        /// <summary>
        /// Convert to incompatible type.
        /// </summary>
        [Test, ExpectedException(typeof(NotSupportedException))]
        public void ConvertIncompatibleType3()
        {
            converter.Convert("12.4", typeof(int));
        }

    }

}
