// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.FunctionalTests
{
    /// <summary>
    /// Functional tests for the Change Properties Values use case.
    /// </summary>
    [TestFixture]
    public class ChangePropertiesValuesTestCase
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;
        
        /// <summary>
        /// Set up.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
        }      
        
        /// <summary>
        /// Test set value.
        /// </summary>
        [Test]
        public void TestSetValue()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            String values = cm.GetValue("section1", "prop1");
            Assertion.Assert(values != null && values.Equals("value1"));
            
            Assertion.Assert(cm.SetValue("section1", "prop1", "newvalue"));
            
            values = cm.GetValue("section1", "prop1");
            Assertion.Assert(values != null && values.Equals("newvalue"));
            
            String[] vals = cm.GetValues("section1", "prop1");
            Assertion.Assert(vals != null && vals.Length == 1);
            Assertion.Assert(vals[0].Equals("newvalue"));
            
            cm.RemoveFile(@"..\..\test_files\test.ini");
        }
        
        /// <summary>
        /// Test set values.
        /// </summary>
        [Test]
        public void TestSetValues()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            String[] values = cm.GetValues("section1", "prop1");
            Assertion.Assert(values != null && values.Length == 1);
            Assertion.Assert(values[0].Equals("value1"));
            
            Assertion.Assert(cm.SetValues("section1", "prop1",
                new String[] { "newvalue1", "newvalue2"} ));
            
            values = cm.GetValues("section1", "prop1");
            Assertion.Assert(values != null && values.Length == 2);
            
            Assertion.Assert(values[0].Equals("newvalue1") &&
                             values[1].Equals("newvalue2"));
            
            cm.RemoveFile(@"..\..\test_files\test.ini");
        }
    }
}
