// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.FunctionalTests
{
    /// <summary>
    /// Functional tests for the Navigate Namespaces And Properties use case.
    /// </summary>
    [TestFixture]
    public class NavigateNamespacesAndPropertiesTestCase
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;
        
        /// <summary>
        /// Set up.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
        }

        /// <summary>
        /// Test config file Namespaces property.
        /// </summary>
        [Test]
        public void TestConfigFileNamespaces()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            Namespace[] namespaceObject = cf.Namespaces;
            Assertion.AssertNotNull(namespaceObject);
            Assertion.Assert(namespaceObject.Length == 2);
            Assertion.AssertNotNull(namespaceObject[0]);
            Assertion.AssertNotNull(namespaceObject[1]);
            Assertion.Assert(namespaceObject[0].Name.Equals("section1"));
            Assertion.Assert(namespaceObject[1].Name.Equals("section2"));
            cm.RemoveFile(@"..\..\test_files\test.ini");
        }
        
        /// <summary>
        /// Test config manager Namespaces property.
        /// </summary>
        [Test]
        public void TestConfigManagerNamespaces()
        {
            Assertion.AssertNotNull(cm);
            Namespace[] namespaceObject = cm.Namespaces;
            Assertion.AssertNotNull(namespaceObject);
            Assertion.Assert(namespaceObject.Length == 2);
            Assertion.AssertNotNull(namespaceObject[0]);
            Assertion.AssertNotNull(namespaceObject[1]);
            Assertion.Assert(namespaceObject[0].Name.Equals(
                "TopCoder.Util.ConfigurationManager.FunctionalTests1"));
            Assertion.Assert(namespaceObject[1].Name.Equals(
                "TopCoder.Util.ConfigurationManager.FunctionalTests2"));
        }
        
        /// <summary>
        /// Test config manager GetNamespace method.
        /// </summary>
        [Test]
        public void TestConfigManagerGetNamespace()
        {
            Assertion.AssertNotNull(cm);
            Namespace ns1 = cm.GetNamespace(
                "TopCoder.Util.ConfigurationManager.FunctionalTests1");
            Namespace ns2 = cm.GetNamespace(
                "TopCoder.Util.ConfigurationManager.FunctionalTests2");
            Assertion.AssertNotNull(ns1);
            Assertion.AssertNotNull(ns2);
            Assertion.Assert(ns1.Name.Equals(
                "TopCoder.Util.ConfigurationManager.FunctionalTests1"));
            Assertion.Assert(ns2.Name.Equals(
                "TopCoder.Util.ConfigurationManager.FunctionalTests2"));
        }
        
        /// <summary>
        /// Test config manager GetProperty method.
        /// </summary>
        [Test]
        public void TestConfigManagerGetProperty()
        {
            Assertion.AssertNotNull(cm);
            Property p1 = cm.GetProperty(
                "TopCoder.Util.ConfigurationManager.FunctionalTests1", "p1");
            Assertion.AssertNotNull(p1);
            Assertion.Assert(p1.Name.Equals("p1"));
            Assertion.Assert(p1.Value.Equals("v1"));
        }
        
        /// <summary>
        /// Test Namespace Properties property.
        /// </summary>
        [Test]
        public void TestNamespaceProperties()
        {
            Assertion.AssertNotNull(cm);
            Namespace namespaceObject = cm.GetNamespace(
                "TopCoder.Util.ConfigurationManager.FunctionalTests1");
            Assertion.AssertNotNull(namespaceObject);
            Property[] pp = namespaceObject.Properties;
            Assertion.AssertNotNull(pp);
            Assertion.Assert(pp.Length == 1);
            Assertion.AssertNotNull(pp[0]);
            // Updated test, should have been Value, not Name
            Assertion.Assert(pp[0].Value.Equals("v1"));
        }
        
        /// <summary>
        /// Test Namespace GetProperty method.
        /// </summary>
        [Test]
        public void TestNamespaceGetProperty()
        {
            Assertion.AssertNotNull(cm);
            Namespace namespaceObject = cm.GetNamespace(
                "TopCoder.Util.ConfigurationManager.FunctionalTests1");
            Assertion.AssertNotNull(namespaceObject);
            Property p = namespaceObject.GetProperty("p1");
            Assertion.AssertNotNull(p);
            // Updated test, should have been Value, not Name
            Assertion.Assert(p.Value.Equals("v1"));
        }
        
        /// <summary>
        /// Test Property Name and Value properties.
        /// </summary>
        [Test]
        public void TestPropertyNameAndValue()
        {
            Assertion.AssertNotNull(cm);
            Property p1 = cm.GetProperty(
                "TopCoder.Util.ConfigurationManager.FunctionalTests1", "p1");
            Assertion.AssertNotNull(p1);
            Assertion.Assert(p1.Name.Equals("p1"));
            Assertion.Assert(p1.Value.Equals("v1"));
            // Updated, there are two values for p1, not 1
            Assertion.Assert(p1.Values.Length == 2);
            Assertion.Assert(p1.Values[0].Equals("v1"));
        }
    }
}
