// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.UnitTests
{
    /// <summary>
    /// Unit tests for the Property class
    /// </summary>
    [TestFixture]
    public class PropertyUnitTestCase
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;
        
        /// <summary>
        /// Set up.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
			cm.Clear();
        }

        /// <summary>
        /// Tests the Name field of Property
        /// </summary>
        [Test]
        public void TestName()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            Namespace namespaceObject = cm.GetNamespace("section2");
            Assertion.AssertNotNull(namespaceObject);
            Property prop = namespaceObject.GetProperty("prop1");
            Assertion.AssertNotNull(prop);
            Assertion.AssertEquals("prop1", prop.Name);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            cf = cm.LoadFile(@"..\..\test_files\test3.xml", "override");
            
            namespaceObject = cm.GetNamespace("override");
            Assertion.AssertNotNull(namespaceObject);
            prop = namespaceObject.GetProperty("p1");
            Assertion.AssertNotNull(prop);
            Assertion.AssertEquals("p1", prop.Name);

            cm.RemoveFile(@"..\..\test_files\test3.xml");
        }

        /// <summary>
        /// Tests the Value field of Property
        /// </summary>
        [Test]
        public void TestValue()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            Namespace namespaceObject = cm.GetNamespace("section2");
            Assertion.AssertNotNull(namespaceObject);
            Property prop = namespaceObject.GetProperty("prop1");
            Assertion.AssertNotNull(prop);
            Assertion.AssertEquals("value1", prop.Value);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            cf = cm.LoadFile(@"..\..\test_files\broken.ini", "override");
            
            namespaceObject = cm.GetNamespace("override");
            Assertion.AssertNotNull(namespaceObject);
            prop = namespaceObject.GetProperty("prop5");
            Assertion.AssertNotNull(prop);
            Assertion.AssertEquals("value1", prop.Value);
            prop.Value = "newvalue";
            Assertion.AssertEquals("newvalue", prop.Value);
            Assertion.AssertEquals(1, prop.Values.Length);

            cm.RemoveFile(@"..\..\test_files\broken.ini");
        }

        /// <summary>
        /// Tests the Values field of Property
        /// </summary>
        [Test]
        public void TestValues()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            Namespace namespaceObject = cm.GetNamespace("section2");
            Assertion.AssertNotNull(namespaceObject);
            Property prop = namespaceObject.GetProperty("prop3");
            Assertion.AssertNotNull(prop);
            Assertion.AssertEquals("value1", prop.Value);
            Assertion.AssertEquals(3, prop.Values.Length);
            Assertion.AssertEquals("value3", prop.Values[2]);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            cf = cm.LoadFile(@"..\..\test_files\broken.ini", "override");
            
            namespaceObject = cm.GetNamespace("override");
            Assertion.AssertNotNull(namespaceObject);
            prop = namespaceObject.GetProperty("prop5");
            Assertion.AssertNotNull(prop);
            Assertion.AssertEquals("value1", prop.Value);
            prop.Values = new string[] {"new1", "new2", "new3", "new4"};
            Assertion.AssertEquals("new1", prop.Value);
            Assertion.AssertEquals(4, prop.Values.Length);
            Assertion.AssertEquals("new2", prop.Values[1]);

            cm.RemoveFile(@"..\..\test_files\broken.ini");
        }
    }
}
