// @author TCSDEVELOPER
// @copyright @ 2005, TopCoder, Inc. All rights reserved

using System;
using System.IO;
using System.Collections;
using System.Threading;

namespace TopCoder.Util.ConfigurationManager.StressTests {
    /// <summary>
    /// Some utilities used in Stress Tests
    /// </summary>
    public class StressTestsUtils {

        public string units = "units";

        /// <summary>
        /// Running tests in many threads
        /// </summary>
        /// <param name="testTypeName"></param>
        /// <param name="name"></param>
        /// <param name="acnt"></param>
        /// <param name="nThreads"></param>
        /// <param name="tr"></param>
        /// <param name="pcnt"></param>
        internal void RunInThreads(string testedClass, string name, int acnt, int nThreads, ThreadStart tr, out int pcnt) {
            pcnt = acnt/nThreads;
            Thread []tt = new Thread[nThreads];
            for (int i = 0; i < nThreads; i++) {
                tt[i] = new Thread(tr);
            }
            DateTime t0 = DateTime.Now;
            for (int i = 0; i < nThreads; i++) {
                tt[i].Start();
            }
            for (int i = 0; i < nThreads; i++) {
                tt[i].Join();
            }
            DateTime t1 = DateTime.Now;
            TimeSpan ts = t1-t0;
            long millis = (long)ts.TotalMilliseconds;
            double wps = acnt / ts.TotalSeconds;
            Console.WriteLine("{0} {1}, {2} threads {3} words took {4} millis {5:f2} " + units ,
                testedClass, name, nThreads, acnt, millis, wps);
        }

        private int seed = 999333;

        /// <summary>
        /// random seed generator which should somewhat work with many threads.
        /// (better than timer which can probably provide equal seeds)
        /// </summary>
        /// <returns>new seed</returns>
        internal int NextSeed() {
            seed = 123 + seed * 98747;
            return seed;
        }
    }
}
